@@ -278,7 +278,7 @@ This means that I<modifications to an object will also modify all other objects
 
 This class is most useful for encapsulating "read-only" rows, or other data that is updated very infrequently.  In the C<Category> example above, it would be inefficient to repeatedly load category information in a long-running process (such as a mod_perl Apache web server) if that information changes infrequently.
 
-The memory cache can be cleared for an individual object or all objects of the same class.  There is also support for simple time-based cache expiration.  See the C<clear_object_cache> and C<cached_objects_expire_in> methods in the L<Rose::DB::Object::Metadata> documentation for more information.
+The memory cache can be cleared for an individual object or all objects of the same class.  There is also support for simple time-based cache expiration.  See the L<clear_object_cache|Rose::DB::Object::Metadata/clear_object_cache> and C<cached_objects_expire_in|Rose::DB::Object::Metadata/cached_objects_expire_in> methods in the L<Rose::DB::Object::Metadata> documentation for more information.
 
 Only the methods that are overridden are documented here.  See the L<Rose::DB::Object> documentation for the rest.
 
