@@ -66,7 +66,7 @@ Rose::DB::Object::Metadata::Column::Bitfield - Bitfield column metadata.
 
 Objects of this class store and manipulate metadata for bitfield columns in a database.  Column metadata objects store information about columns (data type, size, etc.) and are responsible for parsing, formatting, and creating object methods that manipulate column values.
 
-This class inherits from C<Rose::DB::Object::Metadata::Column>. Inherited methods that are not overridden will not be documented a second time here.  See the C<Rose::DB::Object::Metadata::Column> documentation for more information.
+This class inherits from L<Rose::DB::Object::Metadata::Column>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column> documentation for more information.
 
 =head1 OBJECT METHODS
 
@@ -82,7 +82,7 @@ Get or set the default value of the column.
 
 =item B<method_maker_class>
 
-Returns C<Rose::DB::Object::MakeMethods::Generic>.
+Returns L<Rose::DB::Object::MakeMethods::Generic>.
 
 =item B<method_maker_type>
 
@@ -90,7 +90,7 @@ Returns C<bitfield>.
 
 =item B<parse_value DB, VALUE>
 
-Convert VALUE to the equivalent C<Bit::Vector> object.  The return value of the column object's C<bits()> method is used to determine the length of the bitfield in bits.  DB is a C<Rose::DB> object that is used as part of the parsing process.  Both arguments are required.
+Convert VALUE to the equivalent C<Bit::Vector> object.  The return value of the column object's C<bits()> method is used to determine the length of the bitfield in bits.  DB is a L<Rose::DB> object that is used as part of the parsing process.  Both arguments are required.
 
 =item B<type>
 
