@@ -53,7 +53,7 @@ Rose::DB::Object::Metadata::Column::Character - Character column metadata.
 
 Objects of this class store and manipulate metadata for character columns in a database.  Column metadata objects store information about columns (data type, size, etc.) and are responsible for creating object methods that manipulate column values.
 
-This class inherits from C<Rose::DB::Object::Metadata::Column::Scalar>. Inherited methods that are not overridden will not be documented a second time here.  See the C<Rose::DB::Object::Metadata::Column::Scalar> documentation for more information.
+This class inherits from L<Rose::DB::Object::Metadata::Column::Scalar>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column::Scalar> documentation for more information.
 
 =head1 OBJECT METHODS
 
@@ -61,7 +61,7 @@ This class inherits from C<Rose::DB::Object::Metadata::Column::Scalar>. Inherite
 
 =item B<method_maker_class>
 
-Returns C<Rose::DB::Object::MakeMethods::Generic>.
+Returns L<Rose::DB::Object::MakeMethods::Generic>.
 
 =item B<method_maker_type>
 
@@ -69,7 +69,7 @@ Returns C<character>.
 
 =item B<parse_value DB, VALUE>
 
-If C<length> is defined, returns VALUE truncated to a maximum of C<length> characters, or padding with spaces to be exactly C<length> characters long.  DB is a C<Rose::DB> object that may be as part of the parsing process.  Both arguments are required.
+If C<length> is defined, returns VALUE truncated to a maximum of C<length> characters, or padding with spaces to be exactly C<length> characters long.  DB is a L<Rose::DB> object that may be as part of the parsing process.  Both arguments are required.
 
 =item B<type>
 
